@@ -1,7 +1,8 @@
 from gc_google_services_api.bigquery import execute_query
 
-from ms_marathon_api.marathon.parsers.parse_table1 import \
-    build_table1_export_query
+from ms_marathon_api.marathon.parsers.parse_table1 import (
+    build_table1_export_query,
+)
 from ms_marathon_api.marathon.queries.bigquery import INSERT_TABLE1
 from ms_marathon_api.marathon.queries.sql_server import SELECT_ALL_TABLE1
 from ms_marathon_api.sql_server.connection import SQLServer
