@@ -1,6 +1,14 @@
+import logging
+
+logging.basicConfig(
+    level=logging.INFO, format="%(asctime)s - %(levelname)s - %(message)s"
+)
+
 try:
     import pyodbc
-except ImportError:
+except ImportError as e:
+    logging.error(e)
+
     from types import SimpleNamespace
 
     pyodbc = SimpleNamespace()
